
/*
*===========================================================
*        File Name: flash.c
*          Version: A1
*          Created: 2015-8-14
*         Revision: 00
*         Compiler: ARMCC.exe V5.03.0.76
*           Author: 
*          Company: Analog Devices Inc
*===========================================================
*/
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include "flash.h"
static unsigned char ErasePage(unsigned long ulSelPage);
static unsigned char MassEraseFlash(void);
static void WriteToFlash (unsigned long *pArray, unsigned long ulStartAddress, unsigned int uiSize);
static void ReadFromFlash(unsigned long *pArray, unsigned long ulStartAddress, unsigned int uiSize);
extern void Flsh_Int_Handler(void);

FLASH_T flash = {
	.erase_page = ErasePage,
	.erase_all = MassEraseFlash,
	.wr = WriteToFlash,
	.rd = ReadFromFlash
};

static unsigned char ErasePage(unsigned long ulSelPage){
 	volatile unsigned int uiPollFEESTA = 0;
	unsigned long ulFEEADR0L = 0;
	
   ulFEEADR0L = ulSelPage;					
   pADI_FEE->FEEKEY =  0xF456;					// Enter User key to allow access to flash
   pADI_FEE->FEEKEY =  0xF123;
   
   uiPollFEESTA = pADI_FEE->FEESTA;					// Read Status to ensure it is clear
   uiPollFEESTA = 0;
   pADI_FEE->FEEADR0L = ulFEEADR0L & 0xFFFF;			// Load FEEADR0L with lower 16 bits [15:0] of Flash page
   pADI_FEE->FEEADR0H = ulFEEADR0L >> 16;				// Load FEEADR0H with bit [16] of Flash page

   pADI_FEE->FEECMD = 0x1;							// Select Page erase command
//   FlashCmdAbort();
/*	Uncomment if using Polling instead of Flash interrupts
	while (((uiPollFEESTA & 0x4) == 0x0) &&		// Wait for Command to complete
    	  ((uiPollFEESTA & 0x30) != 0x30))		// Also check for an abort
	{
		uiPollFEESTA = FEESTA;
	}	*/
	return 1;	
}
static unsigned char MassEraseFlash(void){
   unsigned int uiPollFEESTA = 0;

   pADI_FEE->FEEKEY =  0xF456;						// Enter User key to allow access to flash
   pADI_FEE->FEEKEY =  0xF123;

   pADI_FEE->FEECMD = 0x3;						    // Select Mass erase command
	
	while (((uiPollFEESTA & 0x4) == 0x0) &&	// Wait for Command to complete
		  ((uiPollFEESTA & 0x30) != 0x30))	// Also check for an abort
	{
		uiPollFEESTA = pADI_FEE->FEESTA;
	}
	return 1;	
}
static void WriteToFlash (unsigned long *pArray, unsigned long ulStartAddress, unsigned int uiSize){
   unsigned int uiPollFEESTA = 0;
   volatile unsigned long *flashAddress;
   unsigned int i = 0;
   
   flashAddress = ( unsigned long      *)ulStartAddress;
   FeeWrEn(1);
   uiPollFEESTA = FeeSta();						// Read Status to ensure it is clear
   for (i = 0; i < uiSize; i = i+4)
   { 
      uiPollFEESTA = 0;
      *flashAddress++  = *pArray++;
      do
         {uiPollFEESTA = FeeSta();}
       while((uiPollFEESTA & FEESTA_CMDBUSY) == FEESTA_CMDBUSY);
   }  
   FeeWrEn(0);       // disable a write to Flash memory
}
static void ReadFromFlash(unsigned long *pArray, unsigned long ulStartAddress, unsigned int uiSize){
   volatile unsigned long *flashAddress;
   unsigned int i = 0;

   flashAddress = ( unsigned long      *)ulStartAddress;
   for (i = 0; i < uiSize; i = i+4)
   {
      *pArray++ = *flashAddress++;
   }
}
extern void Flsh_Int_Handler(){
	unsigned long ulAbortAddress = 0;	
	unsigned int uiFEESTA;
	volatile unsigned char ucFlashCmdStatus = 0;
	volatile unsigned char ucWaitForCmdToComplete = 0;
	uiFEESTA = 0;
	uiFEESTA = pADI_FEE->FEESTA;

	if ((uiFEESTA & 0x30) == 0x00)	// Command completed Successfully
	{
	   ucFlashCmdStatus = 0;			// Command passed
	}
	if ((uiFEESTA & 0x30) == 0x10)	// Error: Attempted erase of protected location
	{
	   ucFlashCmdStatus = 1;			// Command failed - protection error
	}
	if ((uiFEESTA & 0x30) == 0x20)	// Error: Sign error or, Erase error
	{
	   	   ucFlashCmdStatus = 2;	// Command failed - Sign/Erase error
	}
	if ((uiFEESTA & 0x30) == 0x30)	// Error: Command aborted.
	{
		 ulAbortAddress = pADI_FEE->FEEADRAH;
		 ulAbortAddress = (ulAbortAddress << 16);
		 ulAbortAddress |= pADI_FEE->FEEADRAL;
		 ucFlashCmdStatus = 3;			// Command failed - Command aborted before complete
	}
	if ((uiFEESTA & 0x8) == 0x8)		// Write Complete
	{
		 
	}
	if ((uiFEESTA & 0x4) == 0x4)		// Command Complete
	{
		 
	}
	ucWaitForCmdToComplete = 0;
}

